@@ -1,25 +1,24 @@
 package ExtUtils::Helpers::Unix;
-{
-  $ExtUtils::Helpers::Unix::VERSION = '0.020';
-}
+$ExtUtils::Helpers::Unix::VERSION = '0.025';
 use strict;
 use warnings FATAL => 'all';
 
 use Exporter 5.57 'import';
-our @EXPORT = qw/make_executable split_like_shell detildefy/;
+our @EXPORT = qw/make_executable detildefy/;
 
 use Carp qw/croak/;
 use Config;
-use Text::ParseWords 3.24 qw/shellwords/;
+
+my $layer = $] >= 5.008001 ? ":raw" : "";
 
 sub make_executable {
 	my $filename = shift;
 	my $current_mode = (stat $filename)[2] + 0;
 	if (-T $filename) {
-		open my $fh, '<:raw', $filename;
+		open my $fh, "<$layer", $filename;
 		my @lines = <$fh>;
 		if (@lines and $lines[0] =~ s{ \A \#! \s* (?:/\S+/)? perl \b (.*) \z }{$Config{startperl}$1}xms) {
-			open my $out, '>:raw', "$filename.new" or croak "Couldn't open $filename.new: $!";
+			open my $out, ">$layer", "$filename.new" or croak "Couldn't open $filename.new: $!";
 			print $out @lines;
 			close $out;
 			rename $filename, "$filename.bak" or croak "Couldn't rename $filename to $filename.bak";
@@ -31,16 +30,6 @@ sub make_executable {
 	return;
 }
 
-sub split_like_shell {
-	my ($string) = @_;
-
-	return if not defined $string;
-	$string =~ s/^\s+|\s+$//g;
-	return if not length $string;
-
-	return shellwords($string);
-}
-
 sub detildefy {
 	my $value = shift;
 	# tilde with optional username
@@ -55,17 +44,19 @@ sub detildefy {
 
 # ABSTRACT: Unix specific helper bits
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 ExtUtils::Helpers::Unix - Unix specific helper bits
 
 =head1 VERSION
 
-version 0.020
+version 0.025
 
 =for Pod::Coverage make_executable
 split_like_shell
@@ -93,7 +84,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
